Flask-Apx
=========

.. image:: https://github.com/Nux-xader/Flask-Apx/blob/master/images/sample.png
    :target: https://github.com/Nux-xader/Flask-Apx/blob/master/example/app.py
    :alt: Apx example

**apx** is the helper for flask


Notes
=====
This project is still in **BETA**. Please be careful if you want to use it in production environment! Thank You.

Why use apx?
============
* readable your code
* simplyify your code
* speed up the development process

Installation and usage
======================
**installation**

``$ pip install FlaskApx``

or


``$ pip install git+https://github.com/Nux-xader/Flask-Apx``

**Example**

For the example usage of code you can see `here <https://github.com/Nux-xader/Flask-Apx/blob/master/example/app.py>`_
